@@ -1,8 +1,8 @@
 package Locale::Maketext::Test;
-
-use 5.014;
 use strict;
 use warnings;
+
+use 5.014;
 use utf8;
 
 use Try::Tiny;
@@ -10,19 +10,17 @@ use File::Spec;
 use Test::MockModule;
 use Locale::Maketext::ManyPluralForms;
 
+# ABSTRACT: Locale::Maketext::Test
+
 =encoding UTF-8
 
 =head1 NAME
 
 Locale::Maketext::Test
 
-=head1 VERSION
-
-Version 0.04
-
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 SYNOPSIS
 
@@ -46,9 +44,9 @@ our $VERSION = '0.04';
     $response->{status} eq 0;
 
     # check for errors and warnings in case status is 0
-    $response->{errors} = {id => [error1, error2], ru => [error1, error2]};
+    $response->{errors} = {id => [qw(error1 error2)], ru => [qw(error1 error2)]};
     # warnings are only present when debug is set to 1
-    $response->{warnings} = {id => [warn1, warn2], ru => [warn1, warn2]};
+    $response->{warnings} = {id => [qw(warn1 warn2)], ru => [qw(warn1 warn2)]};
 
 =head1 DESCRIPTION
 
@@ -194,7 +192,7 @@ sub BUILD {
         $self->languages(\@lang);
     }
 
-    Locale::Maketext::ManyPluralForms->import({
+    return Locale::Maketext::ManyPluralForms->import({
             '_decode' => 1,
             '_auto'   => $self->auto,
             '*'       => ['Gettext' => File::Spec->rel2abs($self->directory) . '/*.po']});
@@ -402,6 +400,7 @@ sub _bstring {
 
     sub _unread {
         push @stack, @_;
+        return;
     }
 }
 
@@ -422,6 +421,7 @@ sub _get_trans {
             return _cstring($line);
         }
     }
+    return;
 }
 
 sub _get_po {
@@ -434,7 +434,7 @@ sub _get_po {
     my (%header, @ids, $ln);
     my $first = 1;
 
-    open my $f, '<:encoding(UTF-8)', $lang or die "Cannot open $lang: $!\n";
+    open my $f, '<:encoding(UTF-8)', $lang or die "Cannot open $lang: $!\n";    ## no critic (RequireBriefOpen)
     READ:
     while (defined(my $l = _nextline($f))) {
         if ($l =~ /^\s*msgid\s*"(.*)"/) {
@@ -520,47 +520,6 @@ L<http://search.cpan.org/dist/Locale-Maketext-Test/>
 =head1 ACKNOWLEDGEMENTS
 
 
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2016 Binary.com.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
-
-L<http://www.perlfoundation.org/artistic_license_2_0>
-
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
-
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-
 =cut
 
 1;    # End of Locale::Maketext::Test
